Security Advisories (1)
CVE-2022-1664 (2022-05-26)

Dpkg::Source::Archive in dpkg, the Debian package management system, before version 1.21.8, 1.20.10, 1.19.8, 1.18.26 is prone to a directory traversal vulnerability. When extracting untrusted source packages in v2 and v3 source package formats that include a debian.tar, the in-place extraction can lead to directory traversal situations on specially crafted orig.tar and debian.tar tarballs.

NAME

Dpkg::Vendor::Debian - Debian vendor class

DESCRIPTION

This vendor class customizes the behaviour of dpkg scripts for Debian specific behavior and policies.

CHANGES

Version 0.xx

This is a private module.